#
# spec file for package intel-vaapi-driver
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           intel-vaapi-driver
Version:        2.4.1
Release:        5.11
Summary:        Intel Driver for Video Acceleration (VA) API for Linux
License:        MIT AND EPL-1.0
Group:          System/Libraries
URL:            https://github.com/intel/%{name}/
Source0:        %{name}-%{version}.tar.bz2
Source1:        %{name}-%{version}.tar.bz2.sha1sum
Source2:        baselibs.conf
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(libdrm) >= 2.4.45
BuildRequires:  pkgconfig(libdrm_intel)
BuildRequires:  pkgconfig(libva) >= 1.4.0
BuildRequires:  pkgconfig(libva-drm)
BuildRequires:  pkgconfig(libva-wayland)
BuildRequires:  pkgconfig(libva-x11) >= 0.39.4
BuildRequires:  pkgconfig(wayland-client) >= 1.11.0
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)

# Intel graphics hardware only available on these platforms
ExclusiveArch:  %ix86 x86_64
# due to pkg rename vaapi-intel-driver > intel-vaapi-driver
Provides:       vaapi-intel-driver = %{version}
Obsoletes:      vaapi-intel-driver < %{version}
# cause of no default install of xf86-video-intel and is recommended by this package
Supplements:    modalias(xorg-x11-server:pci:v00008086d*sv*sd*bc03sc*i*)

%description
Intel Driver for Libva is a library providing the VA API video acceleration API.

%prep
%autosetup -p1

%build
%meson \
	-Dwith_x11=yes \
	-Dwith_wayland=yes \
	-Denable_hybrid_codec=true \
	-Denable_tests=false \
	%{nil}
%meson_build

%install
%meson_install

%files
%dir %{_libdir}/dri
%{_libdir}/dri/i965_drv_video.so

%changelog
* Mon Oct  4 2021 Stefan Dirsch <sndirsch@suse.com>
- fixed JIRA number in previous changelog
* Mon Sep 27 2021 Stefan Dirsch <sndirsch@suse.com>
- covers jira#SLE/SLE-19361
* Tue Apr 27 2021 Stefan Dirsch <sndirsch@suse.com>
- replaced tarball with official release tarball so it matches
  the updated official sha1sum checksum file
- fixed wrong source lines in specfile
* Tue Apr 27 2021 Stefan Dirsch <sndirsch@suse.com>
- fixed sha1sum checksum file
* Mon Aug 31 2020 Stefan Dirsch <sndirsch@suse.com>
- version 2.4.1 needed for jira#SLE/SLE-12712
* Sat Aug 15 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.4.1:
  * Bump version to 2.4.1 for maintenance release
  * Fix compiler errors with gcc 10
  * Relax the compressed frames minimum size restriction for VP9 encoder
  - remove U_Fix-HEVCe-kernel-compile-error-on-gcc10.patch (upstream)
* Tue Jun  9 2020 Stefan Dirsch <sndirsch@suse.com>
- U_Fix-HEVCe-kernel-compile-error-on-gcc10.patch
  * fixed build against gcc10, which uses -fno-common by default
* Mon Feb 17 2020 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2.4.0
  * Fix the dependency on libEGL (boo#1163093)
  * Fix ROI support
  * Fix FD leaks on Wayland
  * Fix BRC setting
  * Fix VP8 encoder
  * Fix VP9 encoder
  * Fix meson build
- supersedes patches:
  * U_vaapi_Check-interface-from-libva.patch
  * U_vaapi_Revert-VPP-clear-surface.patch
  * U_vaapi_Return-false-instead-assertion-fail.patch
  * U_vaapi_HEVC-encoder-correct-minimal-bitrate.patch
  * U_vaapi_Remove-dep-on-EncRoi-attr.patch
  * U_vaapi_Fix-off-by-one-in-ROI-regions.patch
* Fri Mar 15 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add upstream bug fix patches:
  * U_vaapi_HEVC-encoder-correct-minimal-bitrate.patch
  * U_vaapi_Remove-dep-on-EncRoi-attr.patch
  * U_vaapi_Fix-off-by-one-in-ROI-regions.patch
* Thu Mar  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add upstream bug fix patches:
  * U_vaapi_Check-interface-from-libva.patch
    (gh#intel/intel-vaapi-driver#419).
  * U_vaapi_Revert-VPP-clear-surface.patch
  * U_vaapi_Return-false-instead-assertion-fail.patch
* Tue Feb 19 2019 bjorn.lie@gmail.com
- Pass -Denable_hybrid_codec=true instead of false, build hybrid
  codec support.
* Sat Dec 29 2018 bjorn.lie@gmail.com
- Update to version 2.3.0:
  * Add new PCI ID for KBL and CFL
  * Fix frame corruption when there are big MVs in VP8 encoding
  * Fix dynamically bitrate resetting in AVC encoding
  * Fix build errors when the toolchain doesn't support
  - fstack-protector
  * Fix memory leak issue
  * Make sure the achieved bitrate meet the requirement for VP8
    encoding
  * Optimize VPP on GEN8
- Switch to meson buildsystem:
  * Add meson BuildRequires and macros.
  * Drop libtool BuildRequires.
* Tue Nov 13 2018 sndirsch@suse.com
- Update to version 2.2.0
  * Bump version to 2.2.0
  * Add new PCI ID for KBL-Y
  * Add meson support
  * Fix for VC1 decoding issues
  * Fix VP8 encoding issues
  * Fix the over-run issue in HEVC encoding
  * Fix the max MV length in MPEG-2 encoding
  * Fix packed header mode
  * Fix building issue on Android
* Wed May 30 2018 bjorn.lie@gmail.com
- Add pkgconfig(libva-wayland) BuildRequires: Build full wayland
  support.
* Sun May  6 2018 bjorn.lie@gmail.com
- Update to version 2.1.0:
  * Add support for CannonLake (aka. CNL):
  - Decoding: H.264/MPEG-2/VC-1/JPEG/VP8/HEVC/HEVC 10-bit/VP9/VP9
    10-bit
  - Encoding: H.264/MPEG-2/JPEG/VP8/VP9
  - VPP: CSC/scaling/NoiseReduction/Deinterlacing{Bob,
    MotionAdaptive, MotionCompensated}/ColorBalance/STD
  * Add support for VC1 interlaced video decoding
  * Add support for Stats/PreEnc on GEN9
  * Add support for vaExportSurfaceHandle()
  * Add new PCI IDs for CFL
  * Add minimum resolution query for encoder
  * Enhance the logging to provide informational messages
  * Fix VP9 brc issue on KBL
* Tue Nov 14 2017 zaitor@opensuse.org
- Update to version 2.0.0:
  * Add support for Coffee Lake (aka. CFL).
  * Decoding: H.264/MPEG-2/VC-1/JPEG/VP8/HEVC/HEVC
    10-bit/VP9/VP9 10-bit.
  * Encoding: H.264/MPEG-2/JPEG/VP8/VP9/HEVC/HEVC 10-bit/AVC low
    power CQP/CBR/VBR mode.
  * VPP: CSC/scaling/NoiseReduction/Deinterlacing{Bob,
    MotionAdaptive, MotionCompensated}/ColorBalance/STD.
  * Add support for H264 FEI on SKL.
  * Add support for HEVC ROI encoding.
  * Add support for intensity compensation for VC-1 decoding.
  * Improve the quality of the H264 encoder on BDW/BSW.
  * Improve the CSC performance between I420/NV12/P010/YUY2/VYUY
    format.
  * Improve the performace of va{Get, Put}Image for
    I420/NV12/P010/YUY2/VYUY format.
  * Fix image corruption for VP9 decoding.
  * Fix race condition in wayland support.
  * Fix ROI support in VDEnc support.
  * Fix corrupted stream when using VDEnc CBR/VBR.
  * Fix GCC 7.1.1 warnings/errors.
  * Update the HEVC encoding kernel.
- No longer pass conditional disable-wayland, all currently
  supported versions of openSUSE support wayland.
- Drop u_wayland-includes.diff, seems that it is not really needed
  anymore, builds fine without it, even if the patch applies
  cleanly still.
- Pass explicit enable-drm, enable-x11 and enable-wayland to
  configure, ensure we build all supported backends.
- Following the above, add explicit pkgconfig(libva),
  pkgconfig(libva-drm), pkgconfig(wayland-client), pkgconfig(x11),
  pkgconfig(xext) and pkgconfig(xfixes) BuildRequires: Align with
  what configure looks for.
- Drop obsolete xz BuildRequires: No longer needed.
* Sat Aug 26 2017 jengelh@inai.de
- Remove unnecessary ldconfig calls.
* Fri Aug 18 2017 sndirsch@suse.com
- updated tarball/signature with upstream ones
* Wed Aug 16 2017 chris@computersalat.de
- pkg rename vaapi-intel-driver > intel-vaapi-driver
  * add Obsoletes/Provides
  * add Supplements for xf86-video-intel
* Wed Aug 16 2017 chris@computersalat.de
- Version 1.8.3 - 28.Jun.2017
  * Add support for Gemini Lake (aka. GLK)
  - Decoding: H.264/MPEG-2/VC-1/JPEG/VP8/HEVC/HEVC 10-bit/VP9/VP9 10-bit
  - Encoding: H.264/MPEG-2/JPEG/VP8/VP9/HEVC/HEVC 10-bit/AVC low power CQP mode
  - VPP: CSC/scaling/NoiseReduction/Deinterlacing{
    Bob, MotionAdaptive, MotionCompensated}/ColorBalance/STD
  * Improve the quality of the HEVC encoder on SKL+ for CQP and CBR mode
  * Add support for HEVC VBR mode on SKL+
  * Set the quality range for HEVC / AVC encoder to 7
  * Fix VP9 encoding quality issue on KBL
  * Fix build issue on Android
  * Fix the wrong order for AUD NAL unit in AVC encoder
  * Fix the condition of enabling H.264 MB rate control
  * Fix the memory leak issue in JPEG decoding
* Fri Aug  4 2017 sndirsch@suse.com
- Version 1.8.2
  * Add support for querying slice structure for AVC encoding
  * Add support for AVC multi-slice encoding on SKL+
  * Add support for MVC encoding on SKL+
  * Fix bad frame on SKL and BXT when the quality level is set to 1
* Wed Apr 19 2017 chris@computersalat.de
- fix changes file
  * fix Version string
- sync tarball and sha1sum with upstream
  * sha1sum was also sourcefile
  * source file had wrong checksum
* Tue Apr 18 2017 chris@computersalat.de
- Version 1.8.1 - 10.Apr.2017
  * Add support for VAConfigAttribEncMaxSlices
  * Disable AVC multi-slice encoding on SKL+
  * Disable AVC ROI encoding on SKL+
  * Disable bitrate control per temporal layer on SKL+
  * Disable MVC encoding on SKL+
- add sha1sum file
* Sat Apr 15 2017 chris@computersalat.de
- Version 1.8.0 - 31.Mrz.2017
  * Improve the quality of the H.264 encoder on SKL+ for CQP and CBR mode
  * Improve the quality of the VP8 encoder on BSW+ for CQP and CBR mode
  * Add support for H.264 VBR mode on SKL+
  * Add support for VP8 VBR mode on BSW+
  * Add support for low-power H.264 encoder on BXT and KBL
  * Add support for CBR / VBR with low-power H.264 encoder on SKL+
    (A HuC Firmware and a HuC supported Linux kernel are required)
  * Add support for CSC and scaling with 10bit P010/I010 surface
  * Optimize CSC and scaling with 8bit NV12 and I420 surface
  * Fix the wrong memory object cache setting on SKL+
  * Fix the EU number in media pipeline
  * Fix the wrong bit shift in H.264 encoder
  * Fix the 48bit graphics address on BSW+
  * Fix building on NetBSD
* Tue Apr 11 2017 sndirsch@suse.com
- SLE merge:
  * latest version for sle12 (fate #315643-315645, 319159-319161,
    319618)
* Tue Apr 11 2017 sndirsch@suse.com
- sync openSUSE Leap/SLE build by making use of %%is_opensuse macro;
  we don't build wayland on SLE, but enable it on Leap
* Mon Jan 30 2017 seanvk@posteo.de
- Intel vaapi driver project has moved to github
  Updating package for new project location
  project location : http://github.com/01org/intel-vaapi-driver
* Tue Jan 17 2017 sndirsch@suse.com
- respect X11:XOrg patch guidelines
  * rename U_wayland-includes.diff -> u_wayland-includes.diff
  * fixed patch header in u_wayland-includes.diff
* Sun Jan 15 2017 jengelh@inai.de
- Replace N_libva_Fix_wayland-client.h_include-path.patch,
  N_libva_Fix_wayland-client.h_include-path_1320.patch by
  U_wayland-includes.diff
- Drop redundant %%clean section
* Thu Jan 12 2017 chris@computersalat.de
- fix wayland-client.h include path
  * add N_libva_Fix_wayland-client.h_include-path.patch
  * add N_libva_Fix_wayland-client.h_include-path_1320.patch
- remove n_Don-t-check-WAYLAND_SCANNER-if-wayland-isn-t-used-or.patch
* Sat Dec 31 2016 chris@computersalat.de
- Version 1.7.3 - 10.Nov.2016
  * Add support for HEVC 10bit encoding on KBL
  * Integrate the Google Test Framework for unit testing
  * Add support for bitrate control per temporal layer for SVC-T
  * Fix VA_STATUS_ERROR_UNIMPLEMENTED when sharpening with I420 surface
    (https://bugs.freedesktop.org/show_bug.cgi?id=96987)
  * Fix crop issue when sharpening with NV12 surface
    (https://bugs.freedesktop.org/show_bug.cgi?id=96988)
  * Fix GPU hang issue when using encoding with low power on SKL GT3+
    (https://bugs.freedesktop.org/show_bug.cgi?id=97872)
- rework n_Don-t-check-WAYLAND_SCANNER-if-wayland-isn-t-used-or.patch
* Sat Oct 22 2016 chris@computersalat.de
- Version 1.7.2 - 05.Sep.2016
  * Update PCI IDs for KBL
  * Allow up to 8K JPEG decoding/encoding on SKL+
  * Add support for ROI on IVB+
  * Support I420/YV12 input surface for VP9 encoding
  * Fix assertion failure when decoding stream through VLC
    (https://bugs.freedesktop.org/show_bug.cgi?id=94007)
  * Fix image corruption in ColorBalance and STDE on BDW+
    (https://bugs.freedesktop.org/show_bug.cgi?id=95349)
  * Fix run2run issue in H.264 encoder
    (https://bugs.freedesktop.org/show_bug.cgi?id=96703)
  * Fix video rendering corruption when using VAAPI postproc denoise on 1080p videos
    (https://bugs.freedesktop.org/show_bug.cgi?id=96739)
  * Fix image corruption in ColorBalance with hue=-180
    (https://bugs.freedesktop.org/show_bug.cgi?id=96744)
  * Fix memory leak in VP8 encoding
    (https://bugs.freedesktop.org/show_bug.cgi?id=97272)
* Fri Aug 12 2016 jengelh@inai.de
- Remove useless --with-pic, there are no static libs being built.
* Mon Jul  4 2016 chris@computersalat.de
- fix deps for libva
* Mon Jul  4 2016 sndirsch@suse.com
- Update to version 1.7.1
  * Add support VP9 8bit encoding on KBL
  * Add support for low-power/high-performance H.264 encoder on SKL
  * Fix incorrect color space conversion in driver
    (https://bugs.freedesktop.org/show_bug.cgi?id=94845)
  * Fix FPS caculation for HEVC encoder
  * Fix VP9 10bit decoding issues on KBL
  * Fix the noise issue when VA_FILTER_SCALING_HQ upscaling from
    1280x720 to 1920x1080 with YUY2 format on BDW+
    (https://bugs.freedesktop.org/show_bug.cgi?id=94765)
- n_Don-t-check-WAYLAND_SCANNER-if-wayland-isn-t-used-or.patch
  (reverted) in order to fix build against wayland
* Tue Jun  7 2016 eich@suse.com
- Add baselibs.conf (boo#983331).
* Tue Apr 12 2016 sndirsch@suse.com
- Update to version 1.7.0
  * Add support for Kabylake
  - Decoding: H.264/MPEG-2/VC-1/JPEG/VP8/HEVC/HEVC 10-bit/VP9/VP9 10-bit
  - Encoding: H.264/MPEG-2/JPEG/VP8/HEVC
  - VPP: CSC/scaling/NoiseReduction/Deinterlacing{Bob, MotionAdaptive,
    MotionCompensated}/ColorBalance/STD
  * Add new SKL and BXT PCI IDs
  * Fix lots of VP9 decoding issues on BXT
* Fri Dec 18 2015 zaitor@opensuse.org
- Stop passing --enable-hybrid-codec to configure, this feature
  seems to be not entirely ready yet.
* Thu Dec 17 2015 zaitor@opensuse.org
- Update to version 1.6.2:
  + Add support for Broxton:
  - Decoding: H.264/MPEG-2/VC-1/JPEG/VP8/HEVC/HEVC 10-bit/VP9.
  - Encoding: H.264/JPEG/VP8/HEVC.
  - VPP: CSC/scaling/NoiseReduction/Deinterlacing{Bob,
    MotionAdaptive, MotionCompensated}/ColorBalance/STD.
  + Add support for HEVC CBR on SKL
  + Fix the broken VA_FILTER_SCALING_HQ on SKL
  + Fix the incorrect loading of GPU shaders on GEN8/GEN9
  + Fix the wrong address relocation in VPP on GEN8/GEN9
  + Fix the wrong VAImage foramt (fdo#92088).
  + Fix YUV to RGB conversion on GEN7/GEN8/GEN9.
  + Fix the segmentation fault causing by NULL buffer object on SNB
    (fdo#92811).
  + Fix the wrong coordinate used in VPP (fdo#92811).
- Changes from version 1.6.1:
  + Wrapper other backend driver to support VP9 hybrid decoding on
    BDW/BSW/SKL (--enable-hybrid-codec)
  + Fix HEVC decoding issue on BSW/SKL.
  + Fix HEVC encoding on SKL GT3.
  + Fix GPU hang issue when decoding H.264 MBAFF clips (fdo#91207).
  + Fix issues detected by klockwork scan.
  + Combine csc/scaling together to optimize the performance.
- Pass --enable-hybrid-codec to configure following upstream.
- Add pkgconfig(egl) BuildRequires: Configure checks for it, so
  lets build that support too.
- Stop passing autoreconf, no needed as we do not have any patches.
* Fri Jul 31 2015 zaitor@opensuse.org
- Update to version 1.6.0:
  + Add support for VP8 encode (CQP, CBR) on BSW/SKL.
  + Add support for HEVC decode on BSW.
  + Add support for HEVC encode (CQP) on SKL.
  + Add support for low-power mode (VA_PROC_PIPELINE_FAST) in VPP.
  + Improve the JPEG encode quality on BSW/SKL.
  + Optimize MPEG-2 start code search on IVB.
  + Fix memory leak issue with JPEG decode on IVB/HSW.
  + Fix HEVC decode issue on SKL.
  + Fix GPU hang issue caused by VP8 decode on BDW/BSW.
  + Fix MADI/MCDI issues on SNB/IVB.
* Sun Mar 29 2015 zaitor@opensuse.org
- Update to version 1.5.1:
  + Fix forward reference requirement for Bob deinterlacing.
  + Fix a lot of potential rendering issues on GEN8+.
  + Fix scaling of NV12 surfaces when no output_region is set.
  + Fix the broken attribute setting of i965_GetConfigAttrib.
  + Fix the GetConfigAttributes() for JPEGBaseline profile.
  + Fix the wrong overlap setting for VC-1 decoding on GEN6+.
  + Fix VP8 decoding issue on GEN8+, HW needs 1 extra byte for each
    partition.
  + Fix JPEG encoding issue.
  + Add support for aub dump.
  + Enhance STD on GEN8+.
  + Implement max width and height in QuerySurfaceAttributes.
  + Add new SKL PCI ids.
* Sun Feb  8 2015 zaitor@opensuse.org
- Update to version 1.5.0:
  + Add support for Skylake.
  - Decoding: H.264/MPEG-2/VC-1/JPEG/VP8/HEVC.
  - Encoding: H.264/MPEG-2/JPEG.
  - VPP: CSC/scaling/NoiseReduction/Deinterlacing{Bob,
    MotionAdaptive, MotionCompensated}/ColorBalance/STD.
  + Add support for JPEG encoding on Braswell.
  + Add enhancement for video post/pre processing.
  + Fix out of tree builds.
* Mon Oct 27 2014 sndirsch@suse.com
- Update to 1.4.1; changes since release 1.2.0:
  * support for more GPUs
  * bunch of fixes
  * new features
* Wed Jul 10 2013 hrvoje.senjan@gmail.com
- Update to 1.2.0:
  * Support the new H.264 encoding API on SNB/IVB/HSW
  * MPEG-2 encoding on IVB/HSW
  * Video process on ILK/SNB/IVB/HSW
  * Implement vaQuerySurfaceAttributes()
  * Implement the new version of vaCreateSurfaces()
  * Optimize H.264 encoding on IVB/HSW
- Bump the libdrm and libva as per upstream change
* Tue Mar 19 2013 kkhere.geo@gmail.com
- Version 1.0.20 - 18.Mar.2013
  * Add support for wayland 1.0 protocol (Rob Bradford)
  * Add global alpha support for subpicture
  * Add support for IA88/AI88 subpicture
  * Support up to 4 subpictures for each VA surface
  * Update PCI IDs for Haswell CRW
  * Automake 1.13 fixups (Armin K)
  * Fix libva-intel-driver-1.0.19 display corruption on IVB GT1
    https://bugs.freedesktop.org/show_bug.cgi?id=57323
  * Fix decoding with FREXT02_JVC_C.264 on SNB
    https://bugs.freedesktop.org/show_bug.cgi?id=57720
  * Fix H.264 decoding broken/visual errors on ILK (Tobias Jakobi)
    https://bugs.freedesktop.org/show_bug.cgi?id=58875
  * Fix GPU hung with h.264 video and a resolution of 1920x816 on IVB
    https://bugs.freedesktop.org/show_bug.cgi?id=59050
* Fri Nov  9 2012 kkhere.geo@gmail.com
- update to release 1.0.19
  Version 1.0.19 - 09.Nov.2012
  * Add support for Haswell
  * Add raw DRM support (Dmitry Ermilov)
  * Add Wayland support
  * Add support for display rotation attribute
  * Support 4K encoding on IVB and HSW
  * Drop explicit dependency on X11 and libva-x11
  * Fix VC-1 decoding when VSTRANSFORM is 0
  * Fix SIGSEGV caused by use-after-free of the bufmgr (Stéphane Marchesin)
  * Fix thread safety issue (Gautam)
  * Fix vaUnlockSurface() for libva trace
* Thu Oct 18 2012 kkhere.geo@gmail.com
- update to git master commit b6dd872 as released version does not
  build with the latest libva release
* Wed Jul 11 2012 adrian@suse.de
- exclusive arch for %%ix86 and x86_64
* Fri Jun  1 2012 sndirsch@suse.com
- remove hw Supplements (bnc#764395)
* Wed May 30 2012 crrodriguez@opensuse.org
- Reduce buildRequires to the minimum needed now that
  the dependency chain has been fixed.
* Tue May 29 2012 kkhere.geo@gmail.com
- Update to upstream release 1.0.18
  * Fixes for SandyBridge and IvyBridge, full changelog at
    http://cgit.freedesktop.org/vaapi/intel-driver/
* Fri May 25 2012 sndirsch@suse.com
- license needed to be changed to "MIT and EPL-1.0" (bnc#764135)
* Wed May 23 2012 kkhere.geo@gmail.com
- Convert BuildRequires to pkgconfig(...)
- Build the released version not a git snapshot
- Correct source file name to match the source URL
- Rename package libva-intel-driver to vaapi-intel-driver for
  consistancy with vaapi-dummy-driver
* Tue May 22 2012 crrodriguez@opensuse.org
- Fix/reduce buildRequires, still unneded builddeps due to
  bug in libva-devel ..
* Tue May 22 2012 crrodriguez@opensuse.org
- Initial package for factory, version 1.0.17_git201205040307.
